Class: RosettAi::Doctor::Checks::StaleHomeNnccCheck

Inherits:
Object
  • Object
show all
Includes:
RosettAi::Doctor::Check
Defined in:
lib/rosett_ai/doctor/checks/stale_home_nncc_check.rb

Overview

Warns when a stale .rosett-ai/ directory exists at $HOME level.

Having .rosett-ai/ at $HOME is almost never intentional — it is typically left over from a previous rai init --project run at the home directory. It causes scope resolution confusion because behaviour files in ~/.rosett-ai/conf/behaviour/ shadow XDG-path files.

Author:

  • hugo

  • claude

Instance Attribute Summary

Attributes included from RosettAi::Doctor::Check

#message, #remediation, #status

Method Summary

Methods included from RosettAi::Doctor::Check

included, #name, #run